@@ -15,13 +15,13 @@
 #
 from typing import (
     Any,
-    AsyncIterable,
+    AsyncIterator,
     Awaitable,
     Callable,
-    Iterable,
     Sequence,
     Tuple,
     Optional,
+    Iterator,
 )
 
 from google.cloud.bigquery_connection_v1.types import connection
@@ -74,14 +74,14 @@ class ListConnectionsPager:
         return getattr(self._response, name)
 
     @property
-    def pages(self) -> Iterable[connection.ListConnectionsResponse]:
+    def pages(self) -> Iterator[connection.ListConnectionsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __iter__(self) -> Iterable[connection.Connection]:
+    def __iter__(self) -> Iterator[connection.Connection]:
         for page in self.pages:
             yield from page.connections
 
@@ -136,14 +136,14 @@ class ListConnectionsAsyncPager:
         return getattr(self._response, name)
 
     @property
-    async def pages(self) -> AsyncIterable[connection.ListConnectionsResponse]:
+    async def pages(self) -> AsyncIterator[connection.ListConnectionsResponse]:
         yield self._response
         while self._response.next_page_token:
             self._request.page_token = self._response.next_page_token
             self._response = await self._method(self._request, metadata=self._metadata)
             yield self._response
 
-    def __aiter__(self) -> AsyncIterable[connection.Connection]:
+    def __aiter__(self) -> AsyncIterator[connection.Connection]:
         async def async_generator():
             async for page in self.pages:
                 for response in page.connections:
